@@ -175,6 +175,14 @@ public:
 	void run();
 };
 
+class BookViewOption : public ModeDependentAction {
+
+public:
+	BookViewOption();
+	bool isEnabled() const;
+	void run();
+};
+
 class RedoAction : public ModeDependentAction {
 
 public:
@@ -354,8 +362,11 @@ public:
 class BooksOrderAction : public ModeDependentAction {
 
 public:
-	BooksOrderAction();
+	BooksOrderAction(const std::string &actionId);
 	void run();
+
+private:
+	const std::string myActionId;
 };
 
 class FilterLibraryAction : public ModeDependentAction {
